==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2C6GdInstance.md <==
# AmazonEc2C6GdInstance


```text
aws-20210730/Resource/Compute/AmazonEc2C6GdInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')
```



| Illustration | AmazonEc2C6GdInstance | AmazonEc2C6GdInstanceCard | AmazonEc2C6GdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstance.png) | ![illustration for AmazonEc2C6GdInstance](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstance.Local.png) | ![illustration for AmazonEc2C6GdInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstanceCard.Local.png) | ![illustration for AmazonEc2C6GdInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstanceGroup.Local.png) |




## AmazonEc2C6GdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstance('AmazonEc2C6GdInstance', 'Amazon Ec2 C6 Gd Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstance('AmazonEc2C6GdInstance', 'Amazon Ec2 C6 Gd Instance', 'an optional tech label')
@enduml
```

## AmazonEc2C6GdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceCard('AmazonEc2C6GdInstanceCard', 'Amazon Ec2 C6 Gd Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceCard('AmazonEc2C6GdInstanceCard', 'Amazon Ec2 C6 Gd Instance Card', 'an optional description')
@enduml
```

## AmazonEc2C6GdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceGroup('AmazonEc2C6GdInstanceGroup', 'Amazon Ec2 C6 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceGroup('AmazonEc2C6GdInstanceGroup', 'Amazon Ec2 C6 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Compute/AmazonEc2C6GdInstance.md <==
# AmazonEc2C6GdInstance


```text
aws-20210730/Resource/Compute/AmazonEc2C6GdInstance
```

```text
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')
```



| Illustration | AmazonEc2C6GdInstance | AmazonEc2C6GdInstanceCard | AmazonEc2C6GdInstanceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstance.png) | ![illustration for AmazonEc2C6GdInstance](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstance.Local.png) | ![illustration for AmazonEc2C6GdInstanceCard](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstanceCard.Local.png) | ![illustration for AmazonEc2C6GdInstanceGroup](../../../aws-20210730/Resource/Compute/AmazonEc2C6GdInstanceGroup.Local.png) |




## AmazonEc2C6GdInstance

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstance('AmazonEc2C6GdInstance', 'Amazon Ec2 C6 Gd Instance', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstance
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstance('AmazonEc2C6GdInstance', 'Amazon Ec2 C6 Gd Instance', 'an optional tech label')
@enduml
```

## AmazonEc2C6GdInstanceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceCard('AmazonEc2C6GdInstanceCard', 'Amazon Ec2 C6 Gd Instance Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceCard
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceCard('AmazonEc2C6GdInstanceCard', 'Amazon Ec2 C6 Gd Instance Card', 'an optional description')
@enduml
```

## AmazonEc2C6GdInstanceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceGroup('AmazonEc2C6GdInstanceGroup', 'Amazon Ec2 C6 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEc2C6GdInstanceGroup
include('aws-20210730/Resource/Compute/AmazonEc2C6GdInstance')

' renders the element
AmazonEc2C6GdInstanceGroup('AmazonEc2C6GdInstanceGroup', 'Amazon Ec2 C6 Gd Instance Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
